pub fn parse_escape_sequence(state: &mut ParserState<'_>) -> Result<char>Expand description
consumes an escape sequence and returns the intended character
pub fn parse_escape_sequence(state: &mut ParserState<'_>) -> Result<char>consumes an escape sequence and returns the intended character