assert_char

Function assert_char 

pub fn assert_char(
    state: &mut ParserState<'_>,
    c: char,
    ignore_case: bool,
) -> Result<()>
assert that the current character is the expected character c

if ignore_case is true the check will be preformed without considering the case of the character