pub fn assert_char(
state: &mut ParserState<'_>,
c: char,
ignore_case: bool,
) -> Result<()>Expand description
assert that the current character is the expected character c
if ignore_case is true the check will be preformed without considering the case of the character